@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   dev = "png",
   collapse = TRUE,
@@ -21,6 +21,7 @@ library(dplyr)
 library(table1)
 library(egg)
 library(data.table)
+library(ggh4x)
 library(patchwork)
 theme_set(theme_bw())
 #utility function to simulate varying one covariate at a time keeping the rest at the reference
@@ -148,20 +149,34 @@ outputsim$SEX <- factor(outputsim$SEX, labels="Female")
 set.seed(678549)
 plotdata <- outputsim[ID %in% sample(unique(ID), 500)]
 
+# New facet label names for dose variable
+albumin.labs <- c("albumin: 45 ng/mL")
+names(albumin.labs) <- c("45")
+wt.labs <- c("weight: 85 kg")
+names(wt.labs) <- c("85")
+
+
 p1 <- ggplot(plotdata, aes(time, CP, group = ID)) +
   geom_line(alpha = 0.2, size = 0.1) +
-  facet_grid(~ WT + SEX + ALB, labeller = label_both) +
+  facet_grid(~ WT + ALB + SEX,
+             labeller =  labeller(ALB = albumin.labs,
+                                  WT = wt.labs)) +
   labs(y = "Plasma Concentrations", x = "Time (h)")
 
 p2 <- ggplot(plotdata, aes(time, CP, group = ID)) +
   geom_line(alpha = 0.2, size = 0.1) +
-  facet_grid(~ WT + SEX + ALB, labeller = label_both) +
+  facet_grid(~ WT + ALB + SEX,
+             labeller =  labeller(ALB = albumin.labs,
+                                  WT = wt.labs)) +
   scale_y_log10() +
-  labs(y = expression(Log[10]~Plasma~Concentrations), x = "Time (h)")
+  labs(y = "Plasma~Concentrations\n(logarithmic scale)", x = "Time (h)")
+  #labs(y = expression(Log[10]~Plasma~Concentrations), x = "Time (h)")+
+
+
 
 egg::ggarrange(p1, p2, ncol = 2)
 
-## ----computenca , fig.width=7 , message=FALSE---------------------------------
+## ----computenca, fig.width=7 , message=FALSE----------------------------------
 derive.exposure <- function(time, CP) {
   n <- length(time)
   x <- c(
@@ -242,7 +257,7 @@ bsvranges
 ## ----covcomb , fig.width=7----------------------------------------------------
 reference.values <- data.frame(WT = 85, ALB = 45, SEX = 0)   
 
-covcomb <- expand.modelframe(
+covcomb <- expand.modelframe( #defined at the top and now expand_modelframe was added
   WT  = c(56, 72, 98, 128), # P05, P25, P50, P75, P95
   ALB = c(40, 50),          # P05, P50, P95
   SEX = c(1),               # Reference is for SEX=0 (female)
@@ -255,7 +270,7 @@ covcomb$ID <- 1:nrow(covcomb)
 
 covcomb
 
-## ---- fig.width=7 ,message=FALSE, fig.height=5--------------------------------
+## ----fig.width=8.5, fig.height=7, ,message=FALSE------------------------------
 idata <- data.table::copy(covcomb)
 idata$covname <-  NULL
 ev1 <- ev(time=0, amt=100, cmt=1)
@@ -271,9 +286,15 @@ outcovcomb<- modcovsim %>%
 
 outcovcomb$SEX <- factor(outcovcomb$SEX, labels=c("Female", "Male"))
 
+albumin.labs <- c("albumin: 40 ng/mL","albumin: 45 ng/mL","albumin: 50 ng/mL")
+names(albumin.labs) <- c("40","45","50")
+wt.labs <- c("weight: 56 kg","weight: 72 kg","weight: 85 kg","weight: 98 kg","weight: 128 kg")
+names(wt.labs) <- c("56","72","85","98","128")
+
 pkprofiletypical <- ggplot(outcovcomb, aes(x=time, y=CP, col=factor(WT), linetype=SEX)) +
-  geom_line(aes(group=ID), alpha=1, size=1.5) +
-  facet_grid(ALB +SEX ~ WT, labeller= labeller(ALB = label_both, SEX = label_value, WT = label_both),
+  geom_line(aes(group=ID), alpha = 1, linewidth = 1) +
+  facet_nested(ALB + SEX ~ WT,
+               labeller= labeller(ALB = albumin.labs, WT = wt.labs, SEX = label_value),
              switch = "y") +
   labs(
     x        = "Time (h)",
@@ -285,31 +306,36 @@ pkprofiletypical <- ggplot(outcovcomb, aes(x=time, y=CP, col=factor(WT), linetyp
 
 pkprofiletypical <- pkprofiletypical +theme_bw(base_size = 13)+
   theme(axis.title.y = element_text(size=15))+
-  guides(colour=guide_legend(override.aes = list(alpha=1,size=0.5)),
-         linetype=guide_legend(override.aes = list(size=0.5)))+
+  guides(colour   = guide_legend(override.aes = list(alpha = 1, linewidth = 1)),
+         linetype = guide_legend(override.aes = list(linewidth = 1), order = 1))+
   coord_cartesian(ylim=c(0,4))
 pkprofiletypical
 
 
-## ---- fig.width=7-------------------------------------------------------------
+## ----fig.width=7--------------------------------------------------------------
 theta <- unclass(as.list(param(modcovsim)))
 theta[c("WT", "SEX", "ALB")] <- NULL
 theta <- unlist(theta)
 as.data.frame(t(theta))
 
+#note that from RsNLME or NONMEM or Monolix the software will give you the varcov just read it it in.
+# example NONMEM  read in your run .cov
+# varcov <- read.csv(paste("runxyz",".cov",sep=""), header=TRUE, skip=1, sep="")
+
 varcov <- cor2cov(
   matrix(0.2, nrow=length(theta), ncol=length(theta)),
-  sd=theta*0.15)
+  sd=theta*0.25)
 rownames(varcov) <- colnames(varcov) <- names(theta)
 as.data.frame(varcov)
 
-## ---- fig.width=7-------------------------------------------------------------
+## ----fig.width=7--------------------------------------------------------------
 set.seed(678549)
 # mvtnorm::rmvnorm is another option that can be explored
+# if you have run a bootstrap just use the parameters data generated using all replicates
 sim_parameters <- MASS::mvrnorm(nsim, theta, varcov, empirical=T) %>% as.data.table
 head(sim_parameters)
 
-## ---- fig.width=7,fig.height=4, fig.height=5----------------------------------
+## ----fig.width=8.5, fig.height=7, ,message=FALSE------------------------------
 idata <- data.table::copy(covcomb)
 idata$covname <-  NULL
 ev1       <- ev(time=0, amt=100, cmt=1)
@@ -338,37 +364,24 @@ summary_conc <- function(CP) {
   data.table(paramname=names(x), paramvalue=x)
 }
 
-# pkprofileuncertainty <- ggplot(iter_sims, aes(x=time, y=CP, col=factor(WT), linetype=SEX)) +
-#   geom_line(aes(group=interaction(ID, rep)), alpha=0.1, size=0.1) +
-#   geom_line(data = outcovcomb, aes(group=interaction(ID)),
-#             alpha= 1, size=0.7, colour = "black") +
-#   facet_grid(ALB +SEX ~ WT, labeller= labeller(ALB = label_both, SEX = label_value, WT = label_both),
-#              switch = "y") +
-#   labs(
-#     x        = "Time (h)",
-#     y        = "Plasma Concentrations",
-#     linetype = "Sex",
-#     colour   = "Uncertainty\nReplicates\nWeight",
-#     caption  = "Simulation with Uncertainty, without BSV") +
-#   coord_cartesian(ylim=c(0,3.5))+
-#   guides(colour = guide_legend(override.aes = list(alpha = 1)))+
-#   theme_bw(base_size = 13)+
-#   theme(axis.title.y = element_text(size=15))+
-#   guides(colour=guide_legend(override.aes = list(alpha=1,size=0.5)),
-#          linetype=guide_legend(override.aes = list(size=0.5)))+
-#   coord_cartesian(ylim=c(0,4))
-
 iter_sims_sum <- iter_sims[, summary_conc(CP), by=.( time, WT, SEX, ALB)]
 iter_sims_sum <- spread(iter_sims_sum,paramname,paramvalue)
 iter_sims_sum <- as.data.frame(iter_sims_sum)
 
+albumin.labs <- c("albumin: 40 ng/mL","albumin: 45 ng/mL","albumin: 50 ng/mL")
+names(albumin.labs) <- c("40","45","50")
+wt.labs <- c("weight: 56 kg","weight: 72 kg","weight: 85 kg","weight: 98 kg","weight: 128 kg")
+names(wt.labs) <- c("56","72","85","98","128")
+
 pkprofileuncertainty_sum <- ggplot(iter_sims_sum, aes(x=time, col=factor(WT),
                       fill=factor(WT),
                       linetype=SEX)) +
-  geom_ribbon((aes(ymin= `Clow.5%` ,ymax=`Cup.95%`)), alpha=0.4,linetype=0)+
-  geom_line(aes(y=Cmed),alpha=1 , color ="black")+
-  facet_grid(ALB +SEX ~ WT, labeller= labeller(ALB = label_both, SEX = label_value,
-                                               WT = label_both),switch = "y") +
+  geom_ribbon((aes(ymin= `Clow.5%` ,ymax=`Cup.95%`)), alpha = 0.4, linetype = 0)+
+  geom_line(aes(y=Cmed),alpha=1 , color ="black" , linewidth = 1)+
+  facet_nested(ALB +SEX ~ WT,
+             labeller= labeller(ALB = albumin.labs,
+                                WT = wt.labs,
+                                SEX = label_value),switch = "y") +
   labs(
     x        = "Time (h)",
     y        = "Plasma Concentrations",
@@ -378,15 +391,14 @@ pkprofileuncertainty_sum <- ggplot(iter_sims_sum, aes(x=time, col=factor(WT),
     caption  = "Simulation with Uncertainty, without BSV") +
   theme_bw(base_size = 13)+
   theme(axis.title.y = element_text(size=15))+
-  guides(colour=guide_legend(override.aes = list(alpha=0.4,size=0.4)),
-         fill=guide_legend(override.aes = list(alpha=0.4,size=0.4)),
-         linetype=guide_legend(override.aes = list(size=0.5)))+
+  guides(fill     = guide_legend(override.aes = list(alpha = 0.4, size = 0.4)),
+         linetype = guide_legend(override.aes = list(linewidth = 1), order = 1))+
   coord_cartesian(ylim=c(0,4))
 
 pkprofileuncertainty_sum
 
 
-## ---- fig.width=7, include=TRUE, message=FALSE--------------------------------
+## ----fig.width=7, include=TRUE, message=FALSE---------------------------------
 out.df.univariatecov.nca <- iter_sims[, derive.exposure(time, CP), by=.(rep, ID, WT, SEX, ALB)]
 
 refvalues <- out.df.univariatecov.nca[
@@ -395,7 +407,7 @@ refvalues <- out.df.univariatecov.nca[
 head(data.frame(refvalues))
 
 
-## ---- fig.width=7,fig.height=5 ,message=FALSE---------------------------------
+## ----fig.width=7,fig.height=5 ,message=FALSE----------------------------------
 covcomb$covvalue[covcomb$covname=="WT"] <- paste(covcomb$WT[covcomb$covname=="WT"],"kg")
 covcomb$covvalue[covcomb$covname=="ALB"] <- paste(covcomb$ALB[covcomb$covname=="ALB"],"g/L")                   
 covcomb$covvalue[covcomb$covname=="SEX"] <- "Male"
@@ -458,7 +470,7 @@ pkparametersboxplot<- ggplot(boxplotdat, aes(x=covvalue, y=paramvalue))+
         strip.placement = "outside")
 pkparametersboxplot
 
-## ---- fig.width=7, fig.height=4 ,message=FALSE--------------------------------
+## ----fig.width=7, fig.height=4 ,message=FALSE---------------------------------
 out.df.univariatecov.nca[covname=="WT",      covname2 := "Weight"]
 out.df.univariatecov.nca[covname=="ALB",     covname2 := "Albumin"]
 out.df.univariatecov.nca[covname=="SEX",     covname2 := "Sex"]
@@ -496,7 +508,7 @@ ggplot(out.df.univariatecov.nca[out.df.univariatecov.nca$covname!="REF",], aes(
     quantiles      = c(0.05,0.5, 0.95)) +
   scale_x_continuous(
     breaks = c(0.25, 0.5, 0.8, 1/0.8, 1/0.5, 1/0.25),
-    tran   = "log") +
+    trans  = "log") +
   scale_fill_manual(
     name   = "Probability",
     values = c("white", "#0000FFA0", "#0000FFA0", "white"),
@@ -504,9 +516,11 @@ ggplot(out.df.univariatecov.nca[out.df.univariatecov.nca$covname!="REF",], aes(
   geom_vline(aes(xintercept=1), size=1) +
   theme_bw() +
   labs(x="Effects Relative to Parameter Reference Value", y="")+
-  scale_x_continuous(breaks=c(0.25,0.5,0.8,1/0.8,1/0.5,1/0.25),trans ="log" )
+  scale_x_continuous(breaks=c(0.25,0.5,0.8,1,1/0.8,1/0.5,1/0.25),
+                     labels=c("1/4","1/2","0.8","1","1.25","2","4"),
+                     trans ="log" )
 
-## ---- fig.width=7, fig.height=6-----------------------------------------------
+## ----fig.width=7, fig.height=6------------------------------------------------
 fpdata <- out.df.univariatecov.nca[,
   setNames(as.list(quantile(paramvaluestd, probs=c(0.5, 0.05, 0.95))), c("mid", "lower", "upper")),
   by=.(paramname2, covname2, covvalue)]
@@ -576,7 +590,8 @@ coveffectsplot::forest_plot(fpdata[paramname=="AUC" &
                             plot_table_ratio       = 3,
                             show_table_facet_strip = "none",
                             logxscale              = TRUE,
-                            major_x_ticks          = c(0.5, 0.8, 1/0.8, 1/0.5),
+                            major_x_ticks          = c(0.5, 0.8,1, 1/0.8, 1/0.5),
+                            major_x_labels         = c("1/2", "0.8","1", "1.25", "2"),
                             return_list            = FALSE)
 dev.off()
 
@@ -606,12 +621,13 @@ coveffectsplot::forest_plot(fpdata[paramname=="AUC"],
                             plot_table_ratio = 3,
                             show_table_facet_strip = "none",
                             logxscale = TRUE,
-                            major_x_ticks =    c(0.25,0.5,0.8,1/0.8,1/0.5,1/0.25),
+                            major_x_ticks =    c(0.25,0.5,0.8,1,1/0.8,1/0.5,1/0.25),
+                            major_x_labels = c("1/4","1/2","0.8","1","1.25","2","4"),
                             return_list = FALSE)
 dev.off()
 
 ## ----message=FALSE,fig.width=7------------------------------------------------
-png("./coveffectsplot0.png",width =9 ,height = 6,units = "in",res=72)
+png("./coveffectsplot0.png",width = 9 ,height = 6,units = "in",res=72)
 plotlists <- coveffectsplot::forest_plot(fpdata[paramname=="AUC"],
                             ref_area = c(0.8, 1/0.8),
                             xlabel = "Fold Change Relative to Reference",
@@ -632,12 +648,13 @@ plotlists <- coveffectsplot::forest_plot(fpdata[paramname=="AUC"],
                             plot_table_ratio = 4,
                             show_table_facet_strip = "none",
                             logxscale = TRUE,
-                            major_x_ticks = c(0.25,0.5,0.8,1/0.8,1/0.5,1/0.25),
+                            major_x_ticks = c(0.25,0.5,0.8,1,1/0.8,1/0.5,1/0.25),
+                            major_x_labels = c("1/4","1/2","0.8","1","1.25","2","4"),
                             return_list = TRUE)
 plotlists
 dev.off()
 
-## ---- fig.width=7, fig.height=6, warning=FALSE,message=FALSE------------------
+## ----fig.width=7, fig.height=6, warning=FALSE,message=FALSE-------------------
 main_plot <- plotlists[[1]] + theme(
                panel.spacing=unit(10, "pt"),
                panel.grid=element_blank(),
@@ -683,7 +700,7 @@ egg::ggarrange(
 )
 dev.off()
 
-## ---- fig.width=7, fig.height=6,message=FALSE---------------------------------
+## ----fig.width=7, fig.height=6,message=FALSE----------------------------------
 png("./coveffectsplot6.png",width =9.5 ,height = 6,units = "in",res=72)
 forest_plot(fpdata,
                             ref_area = c(0.8, 1/0.8),
@@ -703,12 +720,13 @@ forest_plot(fpdata,
                             plot_table_ratio = 4,
                             show_table_facet_strip = "none",
                             logxscale = TRUE,
-                            major_x_ticks = c(0.5,0.8,1/0.8,1/0.5),
+                            major_x_ticks = c(0.5,0.8,1,1/0.8,1/0.5),
+                            major_x_labels = c("1/2","0.8","1","1.25","2"),
                             x_label_text_size = 10,
                             return_list = FALSE)
 dev.off()
 
-## ---- fig.width=7, fig.height=6,message=FALSE---------------------------------
+## ----fig.width=7, fig.height=6,message=FALSE----------------------------------
 png("./coveffectsplot7.png",width =9.5 ,height = 6,units = "in",res=72)
 forest_plot(fpdata[paramname!="AUC"],
                             ref_area = c(0.8, 1/0.8),
@@ -733,13 +751,14 @@ forest_plot(fpdata[paramname!="AUC"],
                             plot_table_ratio = 4,
                             show_table_facet_strip = "none",
                             logxscale = TRUE,
-                            major_x_ticks = c(0.5,0.8,1/0.8,1/0.5),
+                            major_x_ticks = c(0.5,0.8,1,1/0.8,1/0.5),
+                            major_x_labels = c("1/2","0.8","1","1.25","2"),
                             legend_space_x_mult = 0.01,
                             legend_position = "right",
                             return_list = FALSE)
 dev.off()
 
-## ---- fig.width=7, fig.height=6,message=FALSE---------------------------------
+## ----fig.width=7, fig.height=6,message=FALSE----------------------------------
 png("./coveffectsplot_color.png",width =9.5 ,height = 6,units = "in",res=72)
 forest_plot(fpdata[paramname!="AUC" &
                      covname!="BSV"&
@@ -762,7 +781,8 @@ forest_plot(fpdata[paramname!="AUC" &
                             table_position = "none",
                             base_size = 12,
                             logxscale = TRUE,
-                            major_x_ticks = c(0.5,0.8,1/0.8,1/0.5),
+                            major_x_ticks = c(0.5,0.8,1,1/0.8,1/0.5),
+                            major_x_labels = c("1/2","0.8","1","1.25","2"),
                             legend_space_x_mult = 0.01,
                             legend_position = "right",
                             return_list = TRUE)[[1]]+
